@@ -4,7 +4,7 @@ import numpy as np
 import sys
 
 
-class RandomForestRegressor(object):
+class RandomForest(object):
 
     def __init__(self, n_trees, trees=[], max_depth=10, gamma=sys.float_info.max, min_split_sample=10):
         self.n_trees = n_trees
@@ -28,4 +28,4 @@ class RandomForestRegressor(object):
         pred_arr = []
         for i in self.trees:
             pred_arr.append(i.predict(X_test))
-        return np.mean(pred_arr, axis=0)
+        return np.mean(pred_arr, axis=0)
\ No newline at end of file
